==> slds-input-radio-group-0.1.5.tgz: package/input-radio-group.spec.md <==
# Component Name

## Overview

The Radio Group element is a control that wraps a number of Radios and allows the user to select one value out of the set. While similar to a Checkbox element, only one Radio element in a particular set can be selected at any given time.

This specification is an extension and union of [SDS Input Radio Group Specification &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/input-radio-group/input-radio-group.spec.md) and [SDS Input Radio Specification &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/input-radio/input-radio.spec.md)

The current implementation is based from the [SLDS Radio Group Specification &rarr;](https://www.lightningdesignsystem.com/components/radio-group/) for the [Lightning Web Component - Radio Group &rarr;](https://developer.salesforce.com/docs/component-library/bundle/lightning-radio-group/example).

## Anatomy and Appearance

### DOM Structure

Note:

- Markup structure mirrors markup in the LBC template.
- `<slot name="help-text"></slot>` is inside the `fieldset` to match LBC.

Input Radio Group

```html
<host class="slds-form-element">
  <fieldset part="input-radio-group">
    <legend part="legend" class="slds-form-element__legend slds-form-element__label"></legend>

    <div part="options" class="slds-form-element__control"></div>

    <slot name="help-text"></slot>
  </fieldset>
</host>
```

Input Radio

```html
<span class="slds-radio">
  <input type="radio" name="" id="" value="" part="radio" />
  <label class="slds-radio__label" for="" part="input-radio">
    <span class="slds-radio_faux" part="indicator"></span>
    <span class="slds-form-element__label" part="label"></span>
  </label>
</span>
```

## API

### Slots

| Slot Name   | Description                                                                    | Fallback Content |
| ----------- | ------------------------------------------------------------------------------ | ---------------- |
| `help-text` | Static help text for this component. Pass a styled element for error messages. | empty            |

### Parts

#### Input Radio Group

| Part Name           | Description                                                                                                               |
| ------------------- | ------------------------------------------------------------------------------------------------------------------------- |
| `input-radio-group` | Main container of the component. This should be a `<fieldset>` element.                                                   |
| `legend`            | Controls the title of the group. This should be a `<legend>` element and be the first direct descendant of the `fieldset` |
| `options`           | Controls list of radios that are part of the group.                                                                       |

#### Input Radio - Type Radio

| Part Name     | Description                                    |
| ------------- | ---------------------------------------------- |
| `radio`       | The hidden input type="radio" (Assistive text) |
| `input-radio` | The component default wrapper                  |
| `indicator`   | The control's `checked` indicator              |
| `label`       | The control's label                            |

#### Input Radio - Type Button

| Part Name | Description                                    |
| --------- | ---------------------------------------------- |
| `radio`   | The hidden input type="radio" (Assistive text) |

### Properties & Attributes

| Attribute     | Type   | Values                                             | Default Value | Description                                                                                                                |
| ------------- | ------ | -------------------------------------------------- | ------------- | -------------------------------------------------------------------------------------------------------------------------- |
| `dir`         | `enum` | `ltr/rtl`                                          | `ltr`         | Modifies the language flow direction.                                                                                      |
| `orientation` | `enum` | `vertical/horizontal`                              | `vertical`    | Modifies layout between radio options for different form layouts. Sets the attribute `aria-orientation` to the `fieldset`. |
| `required`    | `bool` | `true/false`                                       | `false`       | When set, will check that at least one radio is selected on `blur`.                                                        |
| `disabled`    | `bool` | `true/false`                                       | `false`       | When set, users will be unable to navigate to the disabled radio.                                                          |
| `invalid`     | `bool` | `true/false`                                       | `false`       | When set, displays the controls with an invalid appearance.                                                                |
| `checked`     | `bool` | `true/false`                                       | `false`       | When `true`, displays the control with a checked appearance.                                                               |
| `type`        | `enum` | `radio/button`                                     | `radio`       | Changes the appearance of the radio.                                                                                       |
| `variant`     | `enum` | `standard/label-hidden/label-inline/label-stacked` | `standard`    | Changes the appearance of the radio group.                                                                                 |

_NOTES:_

- _SDS uses `aria-invalid="true"`. LBC uses `invalid`. For SDS this may be revisited in the future._
- _The `checked` attribute is optional and useful if the input radios are nested within a different shadow. For general cases in which radios are within the same shadow, the basic `input:checked` will work instead._

### Styling Hooks

Input Radio Group

| Property Name                                       | CSS Property       | Fallback Value                      | Description                                                                |
| --------------------------------------------------- | ------------------ | ----------------------------------- | -------------------------------------------------------------------------- |
| `--slds-c-inputradiogroup-legend-color`             | `color`            | `--sds-g-color-neutral-base-30`     | Color of the radio group legend                                            |
| `--slds-c-inputradiogroup-legend-font-weight`       | `font-weight`      | `--sds-g-font-weight-bold` or `700` | Font weight of the radio group legend                                      |
| `--slds-c-inputradiogroup-legend-font-size`         | `font-size`        | `-sds-g-font-scale-neg-3`           | Font size of the radio group legend                                        |
| `--slds-c-inputradiogroup-legend-spacing-block-end` | `margin-block-end` | `--sds-g-spacing-1`                 | Spacing between the radio group legend and the radio options list          |
| `--slds-c-inputradiogroup-options-spacing-gap`      | `row-gap`          | `--sds-g-spacing-1`                 | Spacing between radio options in either horizontal or vertical orientation |

Input Radio

| Property Name                                                       | CSS Property         | Fallback Value                               | Description                                                                |
| ------------------------------------------------------------------- | -------------------- | -------------------------------------------- | -------------------------------------------------------------------------- |
| `--slds-c-inputradiogroup-indicator-sizing`                         | `width` and `height` | `16px`                                       | The size of the control                                                    |
| `--slds-c-inputradiogroup-indicator-sizing-border`                  | `border`             | `--sds-g-sizing-border-1`                    | The size of the control's border                                           |
| `--slds-c-inputradiogroup-indicator-sizing-border-invalid`          | `border-size`        | `2px`                                        | The size of the control's border when in invalid state                     |
| `--slds-c-inputradiogroup-indicator-color-border`                   | `border-color`       | `--sds-g-color-neutral-base-80`              | The color for the control's border                                         |
| `--slds-c-inputradiogroup-indicator-color-border-focus`             | `border-color`       | `--sds-g-color-brand-base-60`                | The color for the control's border when in checked state                   |
| `--slds-c-inputradiogroup-indicator-color-border-hover`             | `border-color`       | `--sds-g-color-neutral-base-80`              | The color for the control's border when in hovered state                   |
| `--slds-c-inputradiogroup-indicator-color-border-checked`           | `border-color`       | `--sds-g-color-neutral-base-80`              | The color for the control's border when in checked state                   |
| `--slds-c-inputradiogroup-indicator-color-border-checked-focus`     | `border-color`       | `--sds-g-color-brand-base-60`                | The color for the control's border when in checked + focused state         |
| `--slds-c-inputradiogroup-indicator-color-border-checked-hover`     | `border-color`       | `--sds-g-color-neutral-base-80`              | The color for the control's border when in checked + hovered state         |
| `--slds-c-inputradiogroup-indicator-color-border-disabled`          | `border-color`       | `--sds-g-color-neutral-base-80`              | The color for the control's border when in disabled state                  |
| `--slds-c-inputradiogroup-indicator-color-border-invalid`           | `border-color`       | `--sds-g-color-error-base-50`                | The color for the control's border when in invalid state                   |
| `--slds-c-inputradiogroup-indicator-color-background`               | `background-color`   | `--sds-g-color-neutral-base-100`             | The color for the control's background                                     |
| `--slds-c-inputradiogroup-indicator-color-background-focus`         | `background-color`   | `--sds-g-color-neutral-base-100`             | The color for the control's background when in focused state               |
| `--slds-c-inputradiogroup-indicator-color-background-hover`         | `background-color`   | `--sds-g-color-neutral-base-100`             | The color for the control's background when in hovered state               |
| `--slds-c-inputradiogroup-indicator-color-background-checked`       | `background-color`   | `--sds-g-color-neutral-base-100`             | The color for the control's background when in checked state               |
| `--slds-c-inputradiogroup-indicator-color-background-checked-focus` | `background-color`   | `--sds-g-color-neutral-base-100`             | The color for the control's background when in checked + focused state     |
| `--slds-c-inputradiogroup-indicator-color-background-checked-hover` | `background-color`   | `--sds-g-color-neutral-base-100`             | The color for the control's background when in checked + hovered state     |
| `--slds-c-inputradiogroup-indicator-color-background-disabled`      | `background-color`   | `--sds-g-color-neutral-base-95`              | The color for the control's background when in disabled state              |
| `--slds-c-inputradiogroup-indicator-color-background-invalid`       | `background-color`   | `--sds-g-color-neutral-base-100`             | The color for the control's background when in invalid state               |
| `--slds-c-inputradiogroup-indicator-shadow-focus`                   | `box-shadow`         | `0 0 3px var(--sds-g-color-palette-blue-50)` | Box shadow of the control when hovered or focused                          |
| `--slds-c-inputradiogroup-mark-sizing`                              | `width` and `height` | `8px`                                        | The size of the control checked mark                                       |
| `--slds-c-inputradiogroup-mark-color-background`                    | `background-color`   | `--sds-g-color-brand-base-50`                | The color for the control's checked mark background                        |
| `--slds-c-inputradiogroup-mark-color-background-focus`              | `background-color`   | `--sds-g-color-brand-base-50`                | The color for the control's checked mark background when in focused state  |
| `--slds-c-inputradiogroup-mark-color-background-hover`              | `background-color`   | `--sds-g-color-brand-base-50`                | The color for the control's checked mark background when in hovered state  |
| `--slds-c-inputradiogroup-mark-color-background-disabled`           | `background-color`   | `--sds-g-color-neutral-base-60`              | The color for the control's checked mark background when in disabled state |
| `--slds-c-inputradiogroup-mark-color-background-invalid`            | `background-color`   | `--sds-g-color-error-base-60`                | The color for the control's checked mark background when in invalid state  |
| `--slds-c-inputradiogroup-label-spacing-inline-start`               | `column-gap`         | `--sds-g-spacing-2`                          | Determines the amount of space between the indicator and label             |
| `--slds-c-inputradiogroup-label-font-size`                          | `font-size`          | `--sds-g-font-scale-neg-2`                   | Font size of the radio group legend                                        |
| `--slds-c-inputradiogroup-label-color`                              | `color`              | `--sds-g-color-neutral-base-30`              | The color for the label text                                               |
| `--slds-c-inputradiogroup-helptext-font-size`                       | `font-size`          | `--sds-g-font-scale-neg-3`                   | Font size of the help text                                                 |

## Behavior

### States & Interactions

| Interaction  | Event   | Description                                                                  |
| ------------ | ------- | ---------------------------------------------------------------------------- |
| `Click`      | `click` | Listens to events emitted by the input-radios to update the selected option. |
| `Navigation` | `input` | Listens to keyboard events to update the selected option.                    |

## Accessibility

[SDS Input Radio Group - Accessibility &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/input-radio-group/input-radio-group.spec.md#accessibility)

[SDS Input Radio - Accessibility &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/input-radio-group/input-radio.spec.md#accessibility)

## Internationalization

[SDS Input Radio Group - Internationalization &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/input-radio-group/input-radio-group.spec.md#internationalization)

[SDS Input Radio - Internationalization &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/input-radio-group/input-radio.spec.md#internationalization)

## Test Plan

[SDS Input Radio Group - Test Plan &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/input-radio-group/input-radio-group.spec.md#test-plan)

[SDS Input Radio - Test Plan &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/input-radio-group/input-radio.spec.md#test-plan)

==> slds-input-radio-group-0.1.6.tgz: package/input-radio-group.spec.md <==
# Component Name

## Overview

The Radio Group element is a control that wraps a number of Radios and allows the user to select one value out of the set. While similar to a Checkbox element, only one Radio element in a particular set can be selected at any given time.

This specification is an extension and union of [SDS Input Radio Group Specification &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/input-radio-group/input-radio-group.spec.md) and [SDS Input Radio Specification &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/input-radio/input-radio.spec.md)

The current implementation is based from the [SLDS Radio Group Specification &rarr;](https://www.lightningdesignsystem.com/components/radio-group/) for the [Lightning Web Component - Radio Group &rarr;](https://developer.salesforce.com/docs/component-library/bundle/lightning-radio-group/example).

## Anatomy and Appearance

### DOM Structure

Note:

- Markup structure mirrors markup in the LBC template.
- Markup for `type="button"`, is slightly different than `type="radio"`
- `<slot name="help-text"></slot>` is inside the `fieldset` to match LBC.
- The required asterisk and help text are dynamically generated

#### Type Radio

Input Radio Group

```html
<host class="slds-form-element">
  <fieldset part="input-radio-group">
    <legend part="legend" class="slds-form-element__legend slds-form-element__label"></legend>

    <div part="options" class="slds-form-element__control"></div>

    <slot name="help-text"></slot>
  </fieldset>
</host>
```

Input Radio

```html
<span class="slds-radio">
  <input type="radio" name="" id="" value="" part="radio" />
  <label class="slds-radio__label" for="" part="input-radio">
    <span class="slds-radio_faux" part="indicator"></span>
    <span class="slds-form-element__label" part="label">Label</span>
  </label>
</span>
```

#### Type Button

Input Radio Group

```html
<host class="slds-form-element">
  <fieldset part="input-radio-group">
    <legend part="legend" class="slds-form-element__legend slds-form-element__label"></legend>

    <div class="slds-form-element__control" part="options">
      <div class="slds-radio_button-group"></div>
    </div>

    <slot name="help-text"></slot>
  </fieldset>
</host>
```

Input Radio

```html
<span class="slds-button slds-radio_button">
  <input type="radio" name="" id="" value="" part="radio" />
  <label class="slds-radio_button__label" for="">
    <span class="slds-radio_faux">Label</span>
  </label>
</span>
```

#### Required Symbol

The placement for the required asterisk is within the `part="legend"`, before the legend text copy.

```html
<abbr part="required" title="required">*</abbr>
```

Example:

```html
...
<legend part="legend" class="slds-form-element__legend slds-form-element__label">
  <abbr part="required" title="required">*</abbr> Your favorite season of the year?
</legend>
...
```

## API

### Slots

| Slot Name   | Description                                                                    | Fallback Content |
| ----------- | ------------------------------------------------------------------------------ | ---------------- |
| `help-text` | Static help text for this component. Pass a styled element for error messages. | empty            |

### Parts

#### Input Radio Group

| Part Name           | Description                                                                                                               |
| ------------------- | ------------------------------------------------------------------------------------------------------------------------- |
| `input-radio-group` | Main container of the component. This should be a `<fieldset>` element.                                                   |
| `legend`            | Controls the title of the group. This should be a `<legend>` element and be the first direct descendant of the `fieldset` |
| `options`           | Controls list of radios that are part of the group.                                                                       |

#### Input Radio - Type Radio

| Part Name     | Description                                    |
| ------------- | ---------------------------------------------- |
| `radio`       | The hidden input type="radio" (Assistive text) |
| `input-radio` | The component default wrapper                  |
| `indicator`   | The control's `checked` indicator              |
| `label`       | The control's label                            |

#### Input Radio - Type Button

| Part Name | Description                                    |
| --------- | ---------------------------------------------- |
| `radio`   | The hidden input type="radio" (Assistive text) |

### Properties & Attributes

| Attribute     | Type   | Values                                             | Default Value | Description                                                                                                                |
| ------------- | ------ | -------------------------------------------------- | ------------- | -------------------------------------------------------------------------------------------------------------------------- |
| `dir`         | `enum` | `ltr/rtl`                                          | `ltr`         | Modifies the language flow direction.                                                                                      |
| `orientation` | `enum` | `vertical/horizontal`                              | `vertical`    | Modifies layout between radio options for different form layouts. Sets the attribute `aria-orientation` to the `fieldset`. |
| `required`    | `bool` | `true/false`                                       | `false`       | When set, will check that at least one radio is selected on `blur`.                                                        |
| `disabled`    | `bool` | `true/false`                                       | `false`       | When set, users will be unable to navigate to the disabled radio.                                                          |
| `invalid`     | `bool` | `true/false`                                       | `false`       | When set, displays the controls with an invalid appearance.                                                                |
| `checked`     | `bool` | `true/false`                                       | `false`       | When `true`, displays the control with a checked appearance.                                                               |
| `type`        | `enum` | `radio/button`                                     | `radio`       | Changes the appearance of the radio.                                                                                       |
| `variant`     | `enum` | `standard/label-hidden/label-inline/label-stacked` | `standard`    | Changes the appearance of the radio group.                                                                                 |

_NOTES:_

- _SDS uses `aria-invalid="true"`. LBC uses `invalid`. For SDS this may be revisited in the future._
- _The `checked` attribute is optional and useful if the input radios are nested within a different shadow. For general cases in which radios are within the same shadow, the basic `input:checked` will work instead._

### Styling Hooks

Input Radio Group

| Property Name                                       | CSS Property       | Fallback Value                      | Description                                                                |
| --------------------------------------------------- | ------------------ | ----------------------------------- | -------------------------------------------------------------------------- |
| `--slds-c-inputradiogroup-legend-color`             | `color`            | `--sds-g-color-neutral-base-30`     | Color of the radio group legend                                            |
| `--slds-c-inputradiogroup-legend-font-weight`       | `font-weight`      | `--sds-g-font-weight-bold` or `700` | Font weight of the radio group legend                                      |
| `--slds-c-inputradiogroup-legend-font-size`         | `font-size`        | `-sds-g-font-scale-neg-3`           | Font size of the radio group legend                                        |
| `--slds-c-inputradiogroup-legend-spacing-block-end` | `margin-block-end` | `--sds-g-spacing-1`                 | Spacing between the radio group legend and the radio options list          |
| `--slds-c-inputradiogroup-options-spacing-gap`      | `row-gap`          | `--sds-g-spacing-1`                 | Spacing between radio options in either horizontal or vertical orientation |

Input Radio

| Property Name                                                       | CSS Property         | Fallback Value                               | Description                                                                |
| ------------------------------------------------------------------- | -------------------- | -------------------------------------------- | -------------------------------------------------------------------------- |
| `--slds-c-inputradiogroup-indicator-sizing`                         | `width` and `height` | `16px`                                       | The size of the control                                                    |
| `--slds-c-inputradiogroup-indicator-sizing-border`                  | `border`             | `--sds-g-sizing-border-1`                    | The size of the control's border                                           |
| `--slds-c-inputradiogroup-indicator-sizing-border-invalid`          | `border-size`        | `2px`                                        | The size of the control's border when in invalid state                     |
| `--slds-c-inputradiogroup-indicator-color-border`                   | `border-color`       | `--sds-g-color-neutral-base-80`              | The color for the control's border                                         |
| `--slds-c-inputradiogroup-indicator-color-border-focus`             | `border-color`       | `--sds-g-color-brand-base-60`                | The color for the control's border when in checked state                   |
| `--slds-c-inputradiogroup-indicator-color-border-hover`             | `border-color`       | `--sds-g-color-neutral-base-80`              | The color for the control's border when in hovered state                   |
| `--slds-c-inputradiogroup-indicator-color-border-checked`           | `border-color`       | `--sds-g-color-neutral-base-80`              | The color for the control's border when in checked state                   |
| `--slds-c-inputradiogroup-indicator-color-border-checked-focus`     | `border-color`       | `--sds-g-color-brand-base-60`                | The color for the control's border when in checked + focused state         |
| `--slds-c-inputradiogroup-indicator-color-border-checked-hover`     | `border-color`       | `--sds-g-color-neutral-base-80`              | The color for the control's border when in checked + hovered state         |
| `--slds-c-inputradiogroup-indicator-color-border-disabled`          | `border-color`       | `--sds-g-color-neutral-base-80`              | The color for the control's border when in disabled state                  |
| `--slds-c-inputradiogroup-indicator-color-border-invalid`           | `border-color`       | `--sds-g-color-error-base-50`                | The color for the control's border when in invalid state                   |
| `--slds-c-inputradiogroup-indicator-color-background`               | `background-color`   | `--sds-g-color-neutral-base-100`             | The color for the control's background                                     |
| `--slds-c-inputradiogroup-indicator-color-background-focus`         | `background-color`   | `--sds-g-color-neutral-base-100`             | The color for the control's background when in focused state               |
| `--slds-c-inputradiogroup-indicator-color-background-hover`         | `background-color`   | `--sds-g-color-neutral-base-100`             | The color for the control's background when in hovered state               |
| `--slds-c-inputradiogroup-indicator-color-background-checked`       | `background-color`   | `--sds-g-color-neutral-base-100`             | The color for the control's background when in checked state               |
| `--slds-c-inputradiogroup-indicator-color-background-checked-focus` | `background-color`   | `--sds-g-color-neutral-base-100`             | The color for the control's background when in checked + focused state     |
| `--slds-c-inputradiogroup-indicator-color-background-checked-hover` | `background-color`   | `--sds-g-color-neutral-base-100`             | The color for the control's background when in checked + hovered state     |
| `--slds-c-inputradiogroup-indicator-color-background-disabled`      | `background-color`   | `--sds-g-color-neutral-base-95`              | The color for the control's background when in disabled state              |
| `--slds-c-inputradiogroup-indicator-color-background-invalid`       | `background-color`   | `--sds-g-color-neutral-base-100`             | The color for the control's background when in invalid state               |
| `--slds-c-inputradiogroup-indicator-shadow-focus`                   | `box-shadow`         | `0 0 3px var(--sds-g-color-palette-blue-50)` | Box shadow of the control when hovered or focused                          |
| `--slds-c-inputradiogroup-mark-sizing`                              | `width` and `height` | `8px`                                        | The size of the control checked mark                                       |
| `--slds-c-inputradiogroup-mark-color-background`                    | `background-color`   | `--sds-g-color-brand-base-50`                | The color for the control's checked mark background                        |
| `--slds-c-inputradiogroup-mark-color-background-focus`              | `background-color`   | `--sds-g-color-brand-base-50`                | The color for the control's checked mark background when in focused state  |
| `--slds-c-inputradiogroup-mark-color-background-hover`              | `background-color`   | `--sds-g-color-brand-base-50`                | The color for the control's checked mark background when in hovered state  |
| `--slds-c-inputradiogroup-mark-color-background-disabled`           | `background-color`   | `--sds-g-color-neutral-base-60`              | The color for the control's checked mark background when in disabled state |
| `--slds-c-inputradiogroup-mark-color-background-invalid`            | `background-color`   | `--sds-g-color-error-base-60`                | The color for the control's checked mark background when in invalid state  |
| `--slds-c-inputradiogroup-label-spacing-inline-start`               | `column-gap`         | `--sds-g-spacing-2`                          | Determines the amount of space between the indicator and label             |
| `--slds-c-inputradiogroup-label-font-size`                          | `font-size`          | `--sds-g-font-scale-neg-2`                   | Font size of the radio group legend                                        |
| `--slds-c-inputradiogroup-label-color`                              | `color`              | `--sds-g-color-neutral-base-30`              | The color for the label text                                               |
| `--slds-c-inputradiogroup-helptext-font-size`                       | `font-size`          | `--sds-g-font-scale-neg-3`                   | Font size of the help text                                                 |

## Behavior

### States & Interactions

| Interaction  | Event   | Description                                                                  |
| ------------ | ------- | ---------------------------------------------------------------------------- |
| `Click`      | `click` | Listens to events emitted by the input-radios to update the selected option. |
| `Navigation` | `input` | Listens to keyboard events to update the selected option.                    |

## Accessibility

[SDS Input Radio Group - Accessibility &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/input-radio-group/input-radio-group.spec.md#accessibility)

[SDS Input Radio - Accessibility &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/input-radio-group/input-radio.spec.md#accessibility)

## Internationalization

[SDS Input Radio Group - Internationalization &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/input-radio-group/input-radio-group.spec.md#internationalization)

[SDS Input Radio - Internationalization &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/input-radio-group/input-radio.spec.md#internationalization)

## Test Plan

[SDS Input Radio Group - Test Plan &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/input-radio-group/input-radio-group.spec.md#test-plan)

[SDS Input Radio - Test Plan &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/input-radio-group/input-radio.spec.md#test-plan)
